#!/usr/bin/env python

from distutils.core import setup
from distutils.core import Extension
import numpy

#TODO: update paper ref
short_desc = "Package for evaluating the NRSur7dq2 surrogate model"
long_desc = \
"""
NRSur7dq2 is a surrogate model for gravitational waves from numerical
relativity simulations of binary black hole mergers.
It is described in Blackman et al. 2017.
This package provides a class NRSurrogate7dq2 for evaluating the NRSur7dq2
surrogate model.

See the NRSurrogate7dq2 class docstring for usage.
A tutorial Jupyter notebook can be found at
https://www.black-holes.org/surrogates/
"""

extensions = [
    Extension(
                '_NRSur7dq2_utils',
                sources=['NRSur7dq2_utils.c'],
                include_dirs = [numpy.get_include()],
                language='c',
                extra_compile_args = ['-fPIC', '-O3'],
            )
        ]

setup(
        name            = 'NRSur7dq2',
        version         = '1.0',
        description     = short_desc,
        long_description = long_desc,
        author          = 'Jonathan Blackman',
        author_email    = 'jblackman@tapir.caltech.edu',
        url             = 'https://www.black-holes.org/surrogates/',
        ext_modules     = extensions,
        py_modules      = ['NRSur7dq2', 'harmonics'],
    )

